@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 """
 Django utilities for working with Google Chrome Frame.
 
@@ -13,4 +15,7 @@ Refer to the documentation_ for further information.
 
 """
 
-VERSION = '0.9'
+from __future__ import unicode_literals
+
+
+__version__ = '1.1'
