@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 """
 Settings that define behavior of the middleware and decorators.
 
@@ -8,6 +10,11 @@ See the documentation for further details.
 
 """
 
+from __future__ import unicode_literals
+
+
+# TODO: Determine if we even need to account for a lack of settings module, and
+# remove this try/except if necessary.
 try:
     from django.conf import settings
     # Because settings are magical LazySettings objects, it can be
